@@ -33,7 +33,7 @@ vsf_log_init(struct vsf_session* p_sess)
   int retval;
   if (tunable_syslog_enable || tunable_tcp_wrappers)
   {
-    vsf_sysutil_openlog();
+    vsf_sysutil_openlog(1);
   }
   if (!tunable_xferlog_enable && !tunable_dual_log_enable)
   {
@@ -82,9 +82,8 @@ vsf_log_start_entry(struct vsf_session* p_sess, enum EVSFLogEntryType what)
   str_empty(&p_sess->log_str);
   if (vsf_log_type_is_transfer(what))
   {
-    vsf_sysutil_update_cached_time();
-    p_sess->log_start_sec = vsf_sysutil_get_cached_time_sec();
-    p_sess->log_start_usec = vsf_sysutil_get_cached_time_usec();
+    p_sess->log_start_sec = vsf_sysutil_get_time_sec();
+    p_sess->log_start_usec = vsf_sysutil_get_time_usec();
   }
 }
 
@@ -105,6 +104,12 @@ vsf_log_entry_pending(struct vsf_session* p_sess)
   return 1;
 }
 
+void
+vsf_log_clear_entry(struct vsf_session* p_sess)
+{
+  p_sess->log_type = 0;
+}
+
 void
 vsf_log_do_log(struct vsf_session* p_sess, int succeeded)
 {
@@ -168,13 +173,14 @@ static void
 vsf_log_do_log_wuftpd_format(struct vsf_session* p_sess, struct mystr* p_str,
                              int succeeded)
 {
+  static struct mystr s_filename_str;
   long delta_sec;
   enum EVSFLogEntryType what = (enum EVSFLogEntryType) p_sess->log_type;
   /* Date - vsf_sysutil_get_current_date updates cached time */
   str_alloc_text(p_str, vsf_sysutil_get_current_date());
   str_append_char(p_str, ' ');
   /* Transfer time (in seconds) */
-  delta_sec = vsf_sysutil_get_cached_time_sec() - p_sess->log_start_sec;
+  delta_sec = vsf_sysutil_get_time_sec() - p_sess->log_start_sec;
   if (delta_sec <= 0)
   {
     delta_sec = 1;
@@ -188,7 +194,9 @@ vsf_log_do_log_wuftpd_format(struct vsf_session* p_sess, struct mystr* p_str,
   str_append_filesize_t(p_str, p_sess->transfer_size);
   str_append_char(p_str, ' ');
   /* Filename */
-  str_append_str(p_str, &p_sess->log_str);
+  str_copy(&s_filename_str, &p_sess->log_str);
+  str_replace_char(&s_filename_str, ' ', '_');
+  str_append_str(p_str, &s_filename_str);
   str_append_char(p_str, ' ');
   /* Transfer type (ascii/binary) */
   if (p_sess->is_ascii)
@@ -211,14 +219,21 @@ vsf_log_do_log_wuftpd_format(struct vsf_session* p_sess, struct mystr* p_str,
     str_append_text(p_str, "o ");
   }
   /* Access mode: anonymous/real user, and identity */
-  if (p_sess->is_anonymous)
+  if (p_sess->is_anonymous && !p_sess->is_guest)
   {
     str_append_text(p_str, "a ");
     str_append_str(p_str, &p_sess->anon_pass_str);
   }
   else
   {
-    str_append_text(p_str, "r ");
+    if (p_sess->is_guest)
+    {
+      str_append_text(p_str, "g ");
+    } 
+    else
+    {
+      str_append_text(p_str, "r ");
+    }
     str_append_str(p_str, &p_sess->user_str);
   }
   str_append_char(p_str, ' ');
@@ -240,12 +255,16 @@ vsf_log_do_log_vsftpd_format(struct vsf_session* p_sess, struct mystr* p_str,
                              int succeeded, enum EVSFLogEntryType what,
                              const struct mystr* p_log_str)
 {
-  /* Date - vsf_sysutil_get_current_date updates cached time */
-  str_alloc_text(p_str, vsf_sysutil_get_current_date());
-  /* Pid */
-  str_append_text(p_str, " [pid ");
-  str_append_ulong(p_str, vsf_sysutil_getpid());
-  str_append_text(p_str, "] ");
+  str_empty(p_str);
+  if (!tunable_syslog_enable)
+  {
+    /* Date - vsf_sysutil_get_current_date updates cached time */
+    str_append_text(p_str, vsf_sysutil_get_current_date());
+    /* Pid */
+    str_append_text(p_str, " [pid ");
+    str_append_ulong(p_str, vsf_sysutil_getpid());
+    str_append_text(p_str, "] ");
+  }
   /* User */
   if (!str_isempty(&p_sess->user_str))
   {
@@ -255,7 +274,7 @@ vsf_log_do_log_vsftpd_format(struct vsf_session* p_sess, struct mystr* p_str,
   }
   /* And the action */
   if (what != kVSFLogEntryFTPInput && what != kVSFLogEntryFTPOutput &&
-      what != kVSFLogEntryConnection)
+      what != kVSFLogEntryConnection && what != kVSFLogEntryDebug)
   {
     if (succeeded)
     {
@@ -301,6 +320,9 @@ vsf_log_do_log_vsftpd_format(struct vsf_session* p_sess, struct mystr* p_str,
     case kVSFLogEntryChmod:
       str_append_text(p_str, "CHMOD");
       break;
+    case kVSFLogEntryDebug:
+      str_append_text(p_str, "DEBUG");
+      break;
     default:
       bug("bad entry_type in vsf_log_do_log");
       break;
@@ -320,7 +342,8 @@ vsf_log_do_log_vsftpd_format(struct vsf_session* p_sess, struct mystr* p_str,
     str_append_str(p_str, p_log_str);
     str_append_char(p_str, '"');
   }
-  if (what != kVSFLogEntryFTPInput && what != kVSFLogEntryFTPOutput)
+  if (what != kVSFLogEntryFTPInput && what != kVSFLogEntryFTPOutput &&
+      what != kVSFLogEntryDebug)
   {
     if (p_sess->transfer_size)
     {
@@ -330,10 +353,8 @@ vsf_log_do_log_vsftpd_format(struct vsf_session* p_sess, struct mystr* p_str,
     }
     if (vsf_log_type_is_transfer(what))
     {
-      long delta_sec = vsf_sysutil_get_cached_time_sec() -
-                       p_sess->log_start_sec;
-      long delta_usec = vsf_sysutil_get_cached_time_usec() -
-                        p_sess->log_start_usec;
+      long delta_sec = vsf_sysutil_get_time_sec() - p_sess->log_start_sec;
+      long delta_usec = vsf_sysutil_get_time_usec() - p_sess->log_start_usec;
       double time_delta = (double) delta_sec + ((double) delta_usec /
                                                 (double) 1000000);
       double kbyte_rate;
