@@ -18,11 +18,6 @@
 
 static const char* s_p_saved_filename;
 
-/* File local functions */
-static void handle_config_setting(struct mystr* p_setting_str,
-                                  struct mystr* p_value_str,
-                                  int errs_fatal);
-
 /* Tables mapping setting names to runtime variables */
 /* Boolean settings */
 static struct parseconf_bool_setting
@@ -106,6 +101,8 @@ parseconf_bool_array[] =
   { "implicit_ssl", &tunable_implicit_ssl },
   { "sandbox", &tunable_sandbox },
   { "require_ssl_reuse", &tunable_require_ssl_reuse },
+  { "isolate", &tunable_isolate },
+  { "isolate_network", &tunable_isolate_network },
   { 0, 0 }
 };
 
@@ -210,7 +207,7 @@ vsf_parseconf_load_file(const char* p_filename, int errs_fatal)
   {
     if (errs_fatal)
     {
-      die2("cannot open config file:", p_filename);
+      die2("cannot read config file: ", p_filename);
     }
     else
     {
@@ -221,14 +218,15 @@ vsf_parseconf_load_file(const char* p_filename, int errs_fatal)
   {
     struct vsf_sysutil_statbuf* p_statbuf = 0;
     retval = vsf_sysutil_stat(p_filename, &p_statbuf);
-    /* Security: check current user owns the config file. This is a sanity
-     * check for the admin, and is NOT designed to be a check safe from
+    /* Security: check current user owns the config file. These are sanity
+     * checks for the admin, and are NOT designed to be checks safe from
      * race conditions.
      */
     if (vsf_sysutil_retval_is_error(retval) ||
-        vsf_sysutil_statbuf_get_uid(p_statbuf) != vsf_sysutil_getuid())
+        vsf_sysutil_statbuf_get_uid(p_statbuf) != vsf_sysutil_getuid() ||
+        !vsf_sysutil_statbuf_is_regfile(p_statbuf))
     {
-      die("config file not owned by correct user");
+      die("config file not owned by correct user, or not a file");
     }
     vsf_sysutil_free(p_statbuf);
   }
@@ -240,50 +238,55 @@ vsf_parseconf_load_file(const char* p_filename, int errs_fatal)
     {
       continue;
     }
-    /* Split into name=value pair */
-    str_split_char(&config_setting_str, &config_value_str, '=');
-    handle_config_setting(&config_setting_str, &config_value_str, errs_fatal);
+    vsf_parseconf_load_setting(str_getbuf(&config_setting_str), errs_fatal);
   }
   str_free(&config_file_str);
   str_free(&config_setting_str);
   str_free(&config_value_str);
 }
 
-static void
-handle_config_setting(struct mystr* p_setting_str, struct mystr* p_value_str,
-                      int errs_fatal)
+void
+vsf_parseconf_load_setting(const char* p_setting, int errs_fatal)
 {
+  static struct mystr s_setting_str;
+  static struct mystr s_value_str;
+  while (vsf_sysutil_isspace(*p_setting))
+  {
+    p_setting++;
+  }
+  str_alloc_text(&s_setting_str, p_setting);
+  str_split_char(&s_setting_str, &s_value_str, '=');
   /* Is it a string setting? */
   {
     const struct parseconf_str_setting* p_str_setting = parseconf_str_array;
     while (p_str_setting->p_setting_name != 0)
     {
-      if (str_equal_text(p_setting_str, p_str_setting->p_setting_name))
+      if (str_equal_text(&s_setting_str, p_str_setting->p_setting_name))
       {
         /* Got it */
         const char** p_curr_setting = p_str_setting->p_variable;
         if (*p_curr_setting)
         {
-          vsf_sysutil_free((char*)*p_curr_setting);
+          vsf_sysutil_free((char*) *p_curr_setting);
         }
-        if (str_isempty(p_value_str))
+        if (str_isempty(&s_value_str))
         {
           *p_curr_setting = 0;
         }
         else
         {
-          *p_curr_setting = str_strdup(p_value_str);
+          *p_curr_setting = str_strdup(&s_value_str);
         }
         return;
       }
       p_str_setting++;
     }
   }
-  if (str_isempty(p_value_str))
+  if (str_isempty(&s_value_str))
   {
     if (errs_fatal)
     {
-      die2("missing value in config file for: ", str_getbuf(p_setting_str));
+      die2("missing value in config file for: ", str_getbuf(&s_setting_str));
     }
     else
     {
@@ -295,26 +298,26 @@ handle_config_setting(struct mystr* p_setting_str, struct mystr* p_value_str,
     const struct parseconf_bool_setting* p_bool_setting = parseconf_bool_array;
     while (p_bool_setting->p_setting_name != 0)
     {
-      if (str_equal_text(p_setting_str, p_bool_setting->p_setting_name))
+      if (str_equal_text(&s_setting_str, p_bool_setting->p_setting_name))
       {
         /* Got it */
-        str_upper(p_value_str);
-        if (str_equal_text(p_value_str, "YES") ||
-            str_equal_text(p_value_str, "TRUE") ||
-            str_equal_text(p_value_str, "1"))
+        str_upper(&s_value_str);
+        if (str_equal_text(&s_value_str, "YES") ||
+            str_equal_text(&s_value_str, "TRUE") ||
+            str_equal_text(&s_value_str, "1"))
         {
           *(p_bool_setting->p_variable) = 1;
         }
-        else if (str_equal_text(p_value_str, "NO") ||
-                 str_equal_text(p_value_str, "FALSE") ||
-                 str_equal_text(p_value_str, "0"))
+        else if (str_equal_text(&s_value_str, "NO") ||
+                 str_equal_text(&s_value_str, "FALSE") ||
+                 str_equal_text(&s_value_str, "0"))
         {
           *(p_bool_setting->p_variable) = 0;
         }
         else if (errs_fatal)
         {
           die2("bad bool value in config file for: ",
-               str_getbuf(p_setting_str));
+               str_getbuf(&s_setting_str));
         }
         return;
       }
@@ -326,18 +329,18 @@ handle_config_setting(struct mystr* p_setting_str, struct mystr* p_value_str,
     const struct parseconf_uint_setting* p_uint_setting = parseconf_uint_array;
     while (p_uint_setting->p_setting_name != 0)
     {
-      if (str_equal_text(p_setting_str, p_uint_setting->p_setting_name))
+      if (str_equal_text(&s_setting_str, p_uint_setting->p_setting_name))
       {
         /* Got it */
         /* If the value starts with 0, assume it's an octal value */
-        if (!str_isempty(p_value_str) &&
-            str_get_char_at(p_value_str, 0) == '0')
+        if (!str_isempty(&s_value_str) &&
+            str_get_char_at(&s_value_str, 0) == '0')
         {
-          *(p_uint_setting->p_variable) = str_octal_to_uint(p_value_str);
+          *(p_uint_setting->p_variable) = str_octal_to_uint(&s_value_str);
         }
         else
         {
-          *(p_uint_setting->p_variable) = str_atoi(p_value_str);
+          *(p_uint_setting->p_variable) = str_atoi(&s_value_str);
         }
         return;
       }
@@ -346,6 +349,6 @@ handle_config_setting(struct mystr* p_setting_str, struct mystr* p_value_str,
   }
   if (errs_fatal)
   {
-    die2("unrecognised variable in config file: ", str_getbuf(p_setting_str));
+    die2("unrecognised variable in config file: ", str_getbuf(&s_setting_str));
   }
 }
