@@ -583,6 +583,7 @@ handle_pasv(struct vsf_session* p_sess, int is_epsv)
   }
   if (tunable_pasv_address != 0)
   {
+    vsf_sysutil_sockaddr_alloc_ipv4(&s_p_sockaddr);
     /* Report passive address as specified in configuration */
     if (vsf_sysutil_inet_aton(tunable_pasv_address, s_p_sockaddr) == 0)
     {
@@ -737,7 +738,7 @@ handle_retr(struct vsf_session* p_sess)
   }
   else
   {
-    vsf_cmdio_write(p_sess, FTP_TRANSFEROK, "File send OK.");
+    vsf_cmdio_write(p_sess, FTP_TRANSFEROK, "Transfer complete.");
   }
   check_abor(p_sess);
 port_pasv_cleanup_out:
@@ -1108,7 +1109,7 @@ handle_upload_common(struct vsf_session* p_sess, int is_append, int is_unique)
   }
   else
   {
-    vsf_cmdio_write(p_sess, FTP_TRANSFEROK, "File receive OK.");
+    vsf_cmdio_write(p_sess, FTP_TRANSFEROK, "Transfer complete.");
   }
   check_abor(p_sess);
 port_pasv_cleanup_out:
